<?php
#####################################################################################################
#
#					Module pour la plateforme de paiement PayZen
#						Version : 1.1 (révision 52251)
#									########################
#					Développé pour wp-e-commerce
#						Version : 3.8.3
#						Compatibilité plateforme : V2
#									########################
#					Développé par Lyra Network
#						http://www.lyra-network.com/
#						03/10/2013
#						Contact : support@payzen.eu
#
#####################################################################################################


// Load PAYZEN API
require_once(WPSC_FILE_PATH.'/wpsc-merchants/library/payzen_api.php');

$nzshpcrt_gateways[$num] = array(
	'name' => 'PayZen',
	'api_version' => 2.0,
	'class_name' => 'wpsc_merchant_payzen',
	'has_recurring_billing' => false,
	'display_name' => 'PayZen',	
	'wp_admin_cannot_cancel' => true,
	'form' => 'form_payzen',
	'submit_function' => 'submit_payzen',
	'internalname' => 'wpsc_merchant_payzen',
	'image' => WPSC_URL . '/images/payzen.jpg',
	'payment_type' => 'payzen'
);

load_plugin_textdomain('payzen', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/');

class wpsc_merchant_payzen extends wpsc_merchant {
	
	private $payzen_api; // PayZen API
	
	function construct_value_array() {
		global $wpdb, $current_user, $wpsc_gateway;
		
        $this->payzen_api = new PayzenApi();
        
		// Order details params
		
        $currency = $this->payzen_api->findCurrencyByAlphaCode($this->cart_data['store_currency']);
        if($currency != null) {
        	$data['currency'] = $currency->num;
        } else {
        	$this->set_error_message(__('The used currency is not supported.', 'payzen'));
        	$this->return_to_checkout();
        	die();
        }
        
        $amount = $this->cart_data['total_price'];

        // check empty orders
        if($amount <= 0) {
        	$this->return_to_checkout();
        	die();
        }
        
		$data['amount'] = $currency->convertAmountToInteger($amount);
		$data['order_id'] = $this->purchase_id; 
		
		$data['cust_id'] = $current_user->ID; 
		$data['cust_email'] = $this->cart_data['email_address'];
		
		$data['cust_address'] = $this->cart_data['billing_address']['address'];   
		$data['cust_zip'] = $this->cart_data['billing_address']['post_code'];
		$data['cust_country'] = $this->cart_data['billing_address']['country'];
		$data['cust_phone'] = $_POST['collected_data']['18']; 
		$data['cust_city'] = $this->cart_data['billing_address']['city'];
		$data['cust_state'] = $this->cart_data['billing_address']['state'];
		$data['cust_first_name'] = $this->cart_data['billing_address']['first_name'];   
		$data['cust_last_name'] = $this->cart_data['billing_address']['last_name'];
		
		$data['ship_to_first_name'] =  $this->cart_data['shipping_address']['first_name'];  
		$data['ship_to_last_name'] =  $this->cart_data['shipping_address']['last_name'];
		$data['ship_to_street'] = $this->cart_data['shipping_address']['address'];
		$data['ship_to_city'] = $this->cart_data['shipping_address']['city'];
		$data['ship_to_state'] = $_POST['collected_data']['6'];  
		$data['ship_to_country'] = $this->cart_data['shipping_address']['country']; 
		$data['ship_to_zip'] = $this->cart_data['shipping_address']['post_code'];   

		// Platform params
		$data['site_id'] = get_option('payzen_site_id');   
		$data['key_test'] = get_option('payzen_key_test');   
		$data['key_prod'] = get_option('payzen_key_prod');  
		$data['ctx_mode'] = get_option('payzen_ctx_mode');
		$data['platform_url'] = get_option('payzen_gateway_url'); 

		$locale = get_locale() ? substr(get_locale(), 0, 2) : null;
		if($locale && in_array($locale, $this->payzen_api->getSupportedLanguages())) {
			$data['language'] = $locale;
		} else {
			$data['language'] = get_option('payzen_language');
		}		
				
		$available_languages = get_option('payzen_available_languages');
		if(isset($available_languages) && !empty($available_languages)) {
			if (is_array($available_languages)) {
				$data['available_languages'] = implode(';', $available_languages);
			} else { 
				// 1 language selected
				$data['available_languages'] = $available_languages;
			}
		}
		
		$data['capture_delay'] = get_option('payzen_capture_delay');   
				
		$cards = get_option('payzen_payment_cards');
		if(isset($cards) && !empty($cards)) {
			if (is_array($cards)) {
				$data['payment_cards'] = implode(';', $cards);
			} else {
				// 1 card selected
				$data['payment_cards'] = $cards;
			}
		}
		
		// activate 3ds ?
		$threeds_mpi = null;
		$threeds_min_amount = get_option('payzen_3ds_min');
		if($threeds_min_amount != '' && $amount < $threeds_min_amount) {
			$threeds_mpi = '2';
		}
		$data['threeds_mpi'] = $threeds_mpi;
		
		$data['validation_mode'] = get_option('payzen_validation_mode');   
		
		$data['minimum_amount'] = get_option('payzen_minimum_amount');
		$data['maximum_amount'] = get_option('payzen_maximum_amount');
		
		$data['return_mode'] = get_option('payzen_return_mode');   
		$data['redirect_enabled'] = get_option('payzen_redirect_enabled');  
		$data['redirect_success_timeout'] = get_option('payzen_redirect_success_timeout');   
		$data['redirect_success_message'] = get_option('payzen_redirect_success_message');   
		$data['redirect_error_timeout'] = get_option('payzen_redirect_error_timeout');   
		$data['redirect_error_message'] = get_option('payzen_redirect_error_message');		
		$data['order_info'] = session_id();

		// Default return url 
		$return_url = $this->cart_data['notification_url'];
		$return_url = add_query_arg('gateway', 'wpsc_merchant_payzen', $return_url);
		$data['url_return'] = apply_filters('wpsc_payzen_notify_url', $return_url);
		
		// Other params
		include ABSPATH . WPINC . '/version.php';
		$version = $wp_version . '-' . WPSC_VERSION;
		$data['contrib'] = 'wp-e-commerce3.8.3_1.1/' . $version;
		
		$this->collected_gateway_data = $data;
	}
	
	
	function submit() {
		$this->collected_gateway_data = array_map('stripslashes', $this->collected_gateway_data);
		
		$this->payzen_api->setFromArray($this->collected_gateway_data);
		
		$output = '<form action="' . $this->payzen_api->get('platform_url') . '" method="post" name="payzen_form">'
			. $this->payzen_api->getRequestFieldsHtml() . '</form>';
		
			
		echo '<html><body onLoad="document.payzen_form.submit();">'.$output.'</body></html>';
		
		die();
	}
	
	
	function process_gateway_notification() {
		global $wpdb;
		
		$payzen_resp = new PayzenResponse(
				array_map('stripslashes', $_REQUEST), 
				get_option('payzen_ctx_mode'),
				get_option('payzen_key_test'),
				get_option('payzen_key_prod')
		);
		
		$from_server = ($payzen_resp->get('hash') != null);

		if(!$payzen_resp->isAuthentified()) {
			if($from_server) {
				die($payzen_resp->getOutputForGateway('auth_fail'));
			} else {
				// security authentication failed ! notify someone ...
				if(get_option('purch_log_email') != null) {
					$message = $_SERVER['REMOTE_ADDR'] . __(' tries to access the payment notification page without valid signature. It may be a hacking attempt. The details of the call are below.', 'payzen')."\n\r\n\r";
					$message .= "POST:\n\r".print_r($_POST, true)."\n\r\n\r";
					$message .= "GET:\n\r".print_r($_GET, true)."\n\r\n\r";
					$message .= "SERVER:\n\r".print_r($_SERVER, true)."\n\r\n\r";
					wp_mail(get_option('purch_log_email'), __('Authentication failed !', 'payzen'), $message);
				}
				
				exit (__('Authentication failed !', 'payzen'));
			}
		}
		
		$message = '';
		if(get_option('payzen_ctx_mode') == 'TEST') {
			$message .= __('<p><u>GOING INTO PRODUCTION</u></p>You want to know how to put your shop into production mode, please go to this URL : ', 'payzen');
			$message .= '<a href="https://secure.payzen.eu/html/faq/prod" target="_blank">https://secure.payzen.eu/html/faq/prod</a><br /><br />';		
		}
		
		$order_id = $payzen_resp->get('order_id');
		$order = $wpdb->get_row("SELECT `processed`, `sessionid` FROM `" . WPSC_TABLE_PURCHASE_LOGS . "` WHERE `id`='$order_id' LIMIT 1");

		if (!isset($order)){
			if($from_server){
				die($payzen_resp->getOutputForGateway('order_not_found'));
			} else {
				echo __('Could not load any order for your notification : ', 'payzen') . $order_id;
				die();  
			}
		} else {
			if($order->processed == '1') {
				$headers = "MIME-Version: 1.0\r\n";
				$headers .= "Content-Type: text/html; charset=UTF-8\r\n";
				
				if ($payzen_resp->isAcceptedPayment()) {
					$processed_id = '3';
					
					if($from_server) {
						echo($payzen_resp->getOutputForGateway('payment_ok'));
					} else {
						if(get_option('payzen_ctx_mode') == 'TEST' && get_option('purch_log_email') != null) {
							// TEST mode warning : check URL not correctly called
							$message .= __('The automatic notification (peer to peer connection between the payment platform and your shopping cart solution) hasn\'t worked. Have you correctly set up the server URL in your store back-office ?', 'payzen');
							$message .= '<br />' . __('For understanding the problem, please read the documentation of the module : <br />&nbsp;&nbsp;&nbsp;- Chapter &laquo;To read carefully before going further&raquo;<br />&nbsp;&nbsp;&nbsp;- Chapter &laquo;Server URL settings&raquo;','payzen');
							wp_mail(get_option('purch_log_email'), __('Server URL warning', 'payzen'), $message, $headers, array());			
 						}
					}
				} else {
					$processed_id = '6';
					
					if($from_server) {
					  	echo($payzen_resp->getOutputForGateway('payment_ko'));
					} else {
						if(get_option('payzen_ctx_mode') == 'TEST' && get_option('purch_log_email') != null) {
							// TEST mode warning : check URL not correctly called
							$message .= __('The automatic notification (peer to peer connection between the payment platform and your shopping cart solution) hasn\'t worked. Have you correctly set up the server URL in your store back-office ?', 'payzen');
							$message .= '<br />' . __('For understanding the problem, please read the documentation of the module : <br />&nbsp;&nbsp;&nbsp;- Chapter &laquo;To read carefully before going further&raquo;<br />&nbsp;&nbsp;&nbsp;- Chapter &laquo;Server URL settings&raquo;', 'payzen');
							wp_mail(get_option('purch_log_email'), __('Server URL warning', 'payzen'), $message, $headers, array());
						}
					}
				}
				
				// save transaction 
				$this->update_order($order->sessionid, $processed_id, $payzen_resp) ;	
				
			} else { // order already processed
				if ($payzen_resp->isAcceptedPayment()) {
					if($from_server){
						die($payzen_resp->getOutputForGateway('payment_ok_already_done'));
					} else {
						wp_redirect(add_query_arg('sessionid', $order->sessionid, get_option('transact_url')));
						die();
					}
				} else {
					if($from_server){
						die ($payzen_resp->getOutputForGateway('payment_ko_on_order_ok'));
					} else {
						wp_redirect(get_option('transact_url'));
						die();
					}
				}
			}
		}		
	}

	function update_order($session_id, $processed_id, $payzen_resp) {
		global $wpsc_cart, $message_html;
	 
		$from_server = ($payzen_resp->get('hash') != null);
		
		// update order details
		$data = array(
				'processed'  => $processed_id,
				'transactid' => $payzen_resp->get('vads_trans_id'),
				'date'       => time(),
		);
		wpsc_update_purchase_log_details($session_id, $data, 'sessionid');
		
		// restore session in which the customer ordered
		session_id($payzen_resp->get('order_info'));
		session_start();
		
		// re-login customer
		wp_set_current_user(get_userdata($payzen_resp->get('cust_id')));
		
		// reload cart
		wpsc_core_setup_cart();
		
		if($processed_id == '3') {
			// prepare result and delete cart
			transaction_results($session_id, !$from_server, $transaction_id);
		} else {			
			// refresh cart for re-order
			$wpsc_cart->wpsc_refresh_cart_items();
		}
		
		if (!$from_server) {
			// redirect to return URL if not server call
			$url_redirect = get_option('transact_url');
			if($processed_id == '3') {
				$url_redirect = add_query_arg('sessionid', $session_id, $url_redirect) ;
			}
			
			wp_redirect($url_redirect);
		}
		die();
	}
}

add_action('wpsc_inside_shopping_cart', 'payzen_check_amount_restriction');
function payzen_check_amount_restriction() {
	global $wpsc_gateway, $wpsc_cart;

	if((get_option('payzen_minimum_amount') != '' && $wpsc_cart->total_price < get_option('payzen_minimum_amount'))
			|| (get_option('payzen_maximum_amount') != '' && $wpsc_cart->total_price > get_option('payzen_maximum_amount'))) {
		
		foreach ($wpsc_gateway->wpsc_gateways as $index => $gateway) {
			if ($gateway['internalname'] == 'wpsc_merchant_payzen') {
				unset($wpsc_gateway->wpsc_gateways[$index]);
				$wpsc_gateway->gateway_count--;
				break;
			}	
		}
	}
}

function submit_payzen() {  
	if(isset($_POST['payzen_site_id'])) {
		update_option('payzen_site_id', $_POST['payzen_site_id']);
	}
	if(isset($_POST['payzen_key_test'])) {
		update_option('payzen_key_test', $_POST['payzen_key_test']);
	}
	if(isset($_POST['payzen_key_prod'])) {
		update_option('payzen_key_prod', $_POST['payzen_key_prod']);
	}
	if(isset($_POST['payzen_ctx_mode'])) {
		update_option('payzen_ctx_mode', $_POST['payzen_ctx_mode']);
	}
	if(isset($_POST['payzen_gateway_url'])) {
		update_option('payzen_gateway_url', $_POST['payzen_gateway_url']);
	}
  	if(isset($_POST['payzen_language'])) {
    	update_option('payzen_language', $_POST['payzen_language']);
    }

    update_option('payzen_available_languages', isset($_POST['payzen_available_languages']) ? $_POST['payzen_available_languages'] : array());
	
	if(isset($_POST['payzen_capture_delay'])) {
		update_option('payzen_capture_delay', $_POST['payzen_capture_delay']);
	}
	
	update_option('payzen_payment_cards', isset($_POST['payzen_payment_cards']) ? $_POST['payzen_payment_cards'] : array());

	if(isset($_POST['payzen_3ds_min'])) {
		update_option('payzen_3ds_min', $_POST['payzen_3ds_min']);
	}
	if(isset($_POST['payzen_minimum_amount'])) {
		update_option('payzen_minimum_amount', $_POST['payzen_minimum_amount']);
	}
	if(isset($_POST['payzen_maximum_amount'])) {
		update_option('payzen_maximum_amount', $_POST['payzen_maximum_amount']);
	}
	if(isset($_POST['payzen_validation_mode'])) {
		update_option('payzen_validation_mode', $_POST['payzen_validation_mode']);
	}
	if(isset($_POST['payzen_redirect_enabled'])) {
		update_option('payzen_redirect_enabled', $_POST['payzen_redirect_enabled']);
	}    
  	if(isset($_POST['payzen_redirect_success_timeout'])) {
		update_option('payzen_redirect_success_timeout', $_POST['payzen_redirect_success_timeout']);
    }
 	if(isset($_POST['payzen_redirect_success_message'])) {
    	update_option('payzen_redirect_success_message', $_POST['payzen_redirect_success_message']);
    }
  	if(isset($_POST['payzen_redirect_error_timeout'])) {
    	update_option('payzen_redirect_error_timeout', $_POST['payzen_redirect_error_timeout']);
    }
	if(isset($_POST['payzen_redirect_error_message'])) {
		update_option('payzen_redirect_error_message', $_POST['payzen_redirect_error_message']);
	}
	if(isset($_POST['payzen_return_mode'])) {
		update_option('payzen_return_mode', $_POST['payzen_return_mode']);
	}	    
	
	if (!isset($_POST['payzen_form'])) $_POST['payzen_form'] = array();
	foreach((array)$_POST['payzen_form'] as $form => $value) {
	    update_option(('payzen_form_'.$form), $value);
	}
	
	return true;
}

function form_payzen() {
	$payzen_gateway_url = get_option('payzen_gateway_url') == '' ? 'https://secure.payzen.eu/vads-payment/' : get_option('payzen_gateway_url');	
	$payzen_ctx_mode = get_option('payzen_ctx_mode');
	$payzen_language = get_option('payzen_language');
	$payzen_available_languages = get_option('payzen_available_languages') ? get_option('payzen_available_languages') : array();
	$payzen_validation_mode = get_option('payzen_validation_mode') ;
	$payzen_payment_cards = get_option('payzen_payment_cards') ? get_option('payzen_payment_cards') : array();
	$payzen_redirect_enabled = get_option('payzen_redirect_enabled') ;
	$payzen_return_mode = get_option('payzen_return_mode') ;
	
	$notify_url = add_query_arg( 'wpsc_action', 'gateway_notification', (get_option( 'siteurl' ) . "/index.php" ) );
	$notify_url = add_query_arg('gateway', 'wpsc_merchant_payzen', $notify_url);
	$notify_url = apply_filters('wpsc_payzen_notify_url', $notify_url);
	
	// languages and cards
	$payzen_api = new PayzenApi();
	
	$output_language = '';
	$output_available_languages = '';
	
	foreach ($payzen_api->getSupportedLanguages() as $key => $value) {
		$output_language .= '<option ' . ($payzen_language == $key ? 'selected="selected"' : '') . ' value="' . $key . '">' . __($value, 'payzen') . '</option>';
		$output_available_languages .= '<option ' . (in_array($key, $payzen_available_languages) ? 'selected="selected"' : '').' value="' . $key . '">' . __($value, 'payzen') . '</option>';
	}
	
	$output_cards = '';
	foreach ($payzen_api->getSupportedCardTypes() as $key => $value) {
		$output_cards .= '<option ' . (in_array($key, $payzen_payment_cards) ? 'selected="selected"' : '') . ' value="' . $key . '">' . __($value, 'payzen') . '</option>';
	}
	
	$output = '
	    <tr><td colspan="2">
	    <table cellspacing="0" width="100%" style="border:1px solid #DFDFDF; border-top:1px solid #DFDFDF; border-radius:6px 6px 6px 6px;">
		<tr>
	    	<td colspan="2" style="border-bottom: 1px solid #DFDFDF;  text-align: left; vertical-align: middle;padding: 0 0 0 20px;" > 
			    <h3 class="hndle" style="text-transform: uppercase;"> '.__('Module informations', 'payzen').'</h3>
			</td>
		</tr>

		<tr>
			<td style="width:30%;text-align: right;padding-top:3px; padding-bottom:3px;">'.__('Developed by :', 'payzen').'</td>
			<td style="padding-top:3px; padding-bottom:3px;vertical-align: middle; "><a href="http://www.lyra-network.com/" target="_blank">Lyra network</a></td>
		</tr>
		<tr> 
			<td style="text-align: right;padding-top:3px; padding-bottom:3px;">'.__('Contact us :', 'payzen').'</td>
			<td style="padding-top:3px; padding-bottom:3px;vertical-align: middle;"><a href="mailto:support@payzen.eu">support@payzen.eu</a></td>
		</tr>
		<tr>
			<td style="text-align: right;padding-top:3px; padding-bottom:3px;">  '.__('Module version :', 'payzen').'</td>
			<td style="padding-top:3px; padding-bottom:3px;vertical-align: middle;">1.1</td>
		</tr>
		<tr>
			<td style="text-align: right;padding-top:3px; padding-bottom:3px;">'.__('Platform version :','payzen').'</td>
			<td style="padding-top:3px; padding-bottom:3px;vertical-align: middle;">V2</td>
		</tr>
		<tr>
			<td  style="text-align: right;padding-top:3px; padding-bottom:3px;">  '.__('Tested with :','payzen').'</td>
			<td style="padding-top:3px; padding-bottom:3px;vertical-align: middle;">wp-e-commerce 3.8.3</td>
		</tr>
		</table>
		<br/>
		
		<table cellspacing="0" width="100%" style="border:1px solid #DFDFDF; border-top:1px solid #DFDFDF; border-radius:6px 6px 6px 6px;">
		<tr>
	    	<td colspan="2" style="border-bottom: 1px solid #DFDFDF;  text-align: left; vertical-align: middle;   padding: 0 0 0 20px;" > 
			    <h3 class="hndle" style="text-transform: uppercase;">'.__('Payment gateway access', 'payzen').'</h3>
			</td>
		</tr>
		
		<tr>
			<th style="text-align: right; width:30%; border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Site ID','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<input type="text" size="20" value="'.get_option('payzen_site_id').'" name="payzen_site_id"/>
				<br/>
				<span class="small description"> '.__('The identifier provided by your bank','payzen').'</span>
			</td>
		</tr>	
		<tr>
			<th style="text-align: right; border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Certificate in test mode','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<input type="text" size="20" value="'.get_option('payzen_key_test').'" name="payzen_key_test" />
				<br/><span class="small description">'.__('Certificate provided by your bank for test (Available on your back-office)', 'payzen').'</span>
			</td>
		</tr>
		<tr>
			<th style="text-align: right; border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Certificate in production mode','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<input type="text" size="20" value="'.get_option('payzen_key_prod').'" name="payzen_key_prod" />
				<br/><span class="small description">'.__('Certificate provided by your bank (Available on your back-office)', 'payzen').'</span>
			</td>
		</tr>
		<tr>
			<th style="text-align: right; border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Mode','payzen').'</th> 
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<input type="radio" value="TEST" name="payzen_ctx_mode"       id="payzen_ctx1" ' . ($payzen_ctx_mode == 'TEST' ? 'checked="checked"' : '') .'/> <label for="payzen_ctx1">TEST</label> &nbsp;
				<input type="radio" value="PRODUCTION" name="payzen_ctx_mode" id="payzen_ctx2" ' . ($payzen_ctx_mode == 'PRODUCTION' ? 'checked="checked"' : '') .'/> <label for="payzen_ctx2">PRODUCTION</label>
				<br/><span class="small description">'.__('The context mode of this module', 'payzen').'</span>
			</td>
		</tr>
		<tr>
			<th style="text-align: right; border-top:none; border-right:none; border-bottom: 1px solid #DFDFDF; padding-top:3px; padding-bottom:3px;">'.__('Platform URL','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF; padding-top:3px; padding-bottom:3px;">
				<input type="text" size="20" value="'.$payzen_gateway_url.'" name="payzen_gateway_url" />
				<br/><span class="small description">'.__('Link to the payment platform', 'payzen').'</span>
			</td>
		</tr>
		
		<tr>
			<th style="text-align: right; border-top: none; border-right: none; border-bottom: none; padding-top: 3px; padding-bottom: 3px;">'.__('Server URL to copy in your store back-office', 'payzen').'</th>
			<td style="border-right: none; border-top: none; border-bottom: none; padding-top: 3px; padding-bottom: 3px;"><b>'.$notify_url.'</b></td>
		</tr>
		</table><br/>

		<table cellspacing="0" width="100%" style="border:1px solid #DFDFDF; border-top:1px solid #DFDFDF; border-radius:6px 6px 6px 6px;">
		<tr>
	    	<td colspan="2" style="border-bottom: 1px solid #DFDFDF; text-align: left; vertical-align: middle; padding: 0 0 0 20px;" > 
			    <h3 class="hndle" style="text-transform: uppercase;">'.__('Payment page', 'payzen').'</h3>
			</td>
		</tr>
		
		<tr>
			<th style="text-align: right; width:30%;border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Default language','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<select name="payzen_language"  >
								'.$output_language.'            
				</select> 
				<br/><span class="small description">'.__('Select the language to use on the payment page by default', 'payzen').'</span>
			</td>
		</tr>
		<tr>
			<th style="text-align: right; border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Available languages','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<select multiple="multiple" size="8" name="payzen_available_languages[]" style="height: 100px;">
								'.$output_available_languages.'
				</select> 
				<br/><span class="small description">'.__('Select none to use gateway config', 'payzen').'</span>
			</td>
		</tr>
		<tr>
			<th style="text-align: right; border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Capture delay','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<input type="text" size="20" value="'.get_option('payzen_capture_delay').'" name="payzen_capture_delay" />
				<br/><span class="small description">'.__('The number of days before the restoration bank (adjustable in your back-office)', 'payzen').'</span>
			</td>
		</tr>
		<tr>
			<th style="text-align: right; border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Validation mode','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<select name="payzen_validation_mode"  >
								<option '.($payzen_validation_mode == '' ? 'selected="selected"' : '').' value="">'.__('Back-office configuration','payzen').'</option>
					            <option '.($payzen_validation_mode == '0' ? 'selected="selected"' : '').' value="0">'.__('Automatic','payzen').'</option>
								<option '.($payzen_validation_mode == '1' ? 'selected="selected"' : '').' value="1">'.__('Manual','payzen').'</option>
				</select> 
				<br/><span class="small description">'.__('If manual is selected, you will have to confirm payments manually in your back-office','payzen').'</span>
			</td>
		</tr>
		<tr>
			<th style="text-align: right; border-top:none; border-right:none; border-bottom:0px;padding-top:3px; padding-bottom:3px;">'.__('Card Types','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom:0px;padding-top:3px; padding-bottom:3px;">
				<select select multiple="multiple" size="8" name="payzen_payment_cards[]" style="height: 100px;" >
							   '.$output_cards.'
				</select> 
				<br/><span class="small description">'.__('The card type(s) that can be used for the payment','payzen').'</span>
			</td>
		</tr>
		</table><br/>
		
		<table cellspacing="0" width="100%" style="border:1px solid #DFDFDF; border-top:1px solid #DFDFDF; border-radius:6px 6px 6px 6px;">
		<tr>
	    	<td colspan="2" style="border-bottom: 1px solid #DFDFDF;  text-align: left; vertical-align: middle;   padding: 0 0 0 20px;" > 
			    <h3 class="hndle" style="text-transform: uppercase;">'.__('Selective 3DS', 'payzen').'</h3>
			</td>
		</tr>
		
		<tr>
			<th style="text-align: right; width:30%;border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Minimum amount for which activate 3DS','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<input type="text" size="20" value="'.get_option('payzen_3ds_min').'" name="payzen_3ds_min" />
				<br/><span class="small description">'.__('Needs subscription to Selective 3-D Secure option.','payzen').'</span>
			</td>
		</tr>
		
		</table><br/>
		
		<table cellspacing="0" width="100%" style="border:1px solid #DFDFDF; border-top:1px solid #DFDFDF; border-radius:6px 6px 6px 6px;">
		<tr>
	    	<td colspan="2" style="border-bottom: 1px solid #DFDFDF;  text-align: left; vertical-align: middle;   padding: 0 0 0 20px;" > 
			    <h3 class="hndle" style="text-transform: uppercase;">'.__('Amount restrictions', 'payzen').'</h3>
			</td>
		</tr>	
				
		<tr>
			<th style="text-align: right; width:30%;border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Minimum amount','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<input type="text" size="20" value="'.get_option('payzen_minimum_amount').'" name="payzen_minimum_amount" />
				<br/><span class="small description">'.__('Minimum amount for which the payment method is available','payzen').'</span>
			</td>
		</tr>
		<tr>
			<th style="text-align: right; border-top:none; border-right:none; border-bottom:0px;padding-top:3px; padding-bottom:3px;">'.__('Maximum amount','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom:0px;padding-top:3px; padding-bottom:3px;">
				<input type="text" size="20" value="'.get_option('payzen_maximum_amount').'" name="payzen_maximum_amount"/>
				<br/><span class="small description">'.__('Maximum amount for which the payment method is available','payzen').'</span>
			</td>
		</tr>
		</table><br/>

		<table cellspacing="0" width="100%" style="border:1px solid #DFDFDF; border-top:1px solid #DFDFDF; border-radius:6px 6px 6px 6px;">
		<tr>
	    	<td colspan="2" style="border-bottom: 1px solid #DFDFDF;  text-align: left; vertical-align: middle;   padding: 0 0 0 20px;" > 
			    <h3 class="hndle" style="text-transform: uppercase;">'.__('Return to shop', 'payzen').'</h3>
			</td>
		</tr>					

		<tr>
			<th style="text-align: right; width:30%;border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Automatic forward','payzen').'</th> 
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<input type="radio" value="1" name="payzen_redirect_enabled" id="payzen_redirect_enabled1" '.($payzen_redirect_enabled == '1' ? 'checked="checked"' : '') .'/> <label for="payzen_redirect_enabled1">'.__('Yes','payzen').'</label> &nbsp;
				<input type="radio" value="0" name="payzen_redirect_enabled" id="payzen_redirect_enabled2" '.($payzen_redirect_enabled == '0' ? 'checked="checked"' : '') .'/> <label for="payzen_redirect_enabled2">'.__('No','payzen').'</label>
				<br/><span class="small description">'.__('If enabled, the client is automatically forwarded to your site at the end of the payment process','payzen').'</span>
			</td>
		</tr>
		<tr>
			<th style="text-align: right; border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Success forward timeout','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<input type="text" size="20" value="'.get_option('payzen_redirect_success_timeout').'" name="payzen_redirect_success_timeout" />
			    <br/><span class="small description">'.__('Time in seconds (0-300) before the client is automatically forwarded to your site when the payment was successful','payzen').'</span>
			</td>
		</tr>		
		<tr>
			<th style="text-align: right; border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Success forward message','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<input type="text" size="20" value="'.get_option('payzen_redirect_success_message').'" name="payzen_redirect_success_message" />
				<br/><span class="small description">'.__('Message posted on the payment platform before forwarding when the payment was successful','payzen').'</span>
			</td>
		</tr>	
		<tr>
			<th style="text-align: right; border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Failure forward timeout','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<input type="text" size="20" value="'.get_option('payzen_redirect_error_timeout').'" name="payzen_redirect_error_timeout" />
				<br/><span class="small description">'.__('Time in seconds (0-300) before the client is automatically forwarded to your site when the payment failed','payzen').'</span>
			</td>
		</tr>
		<tr>
			<th style="text-align: right; border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Failure forward message','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<input type="text" size="20" value="'.get_option('payzen_redirect_error_message').'" name="payzen_redirect_error_message" />
				<br/><span class="small description">'.__('Message posted on the payment platform before forwarding when the payment failed','payzen').'</span>
			</td>
		</tr>		
		<tr>
			<th style="text-align: right; border-top:none; border-right:none; border-bottom:1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">'.__('Return mode','payzen').'</th>
			<td style="border-right:none;  border-top: none; border-bottom: 1px solid #DFDFDF;padding-top:3px; padding-bottom:3px;">
				<select name="payzen_return_mode">
					<option '.($payzen_return_mode == 'GET' ? 'selected="selected"' : '').' value="GET">GET</option>
		            <option '.($payzen_return_mode == 'POST' ? 'selected="selected"' : '').' value="POST">POST</option>
		  		</select> 
		  		<br/><span class="small description">'.__('Method that will be used for transmitting the payment result from the payment gateway to your store','payzen').'</span>
			</td>
		</tr>
	
		</table><br/>
		</td></tr>
	';
	
	return $output;
}
  
// set default values
function init_payzen() {
	global $wpdb;
	
	$count = $wpdb->get_var("SELECT count(*) FROM wp_options w WHERE option_name LIKE 'payzen_%'");
	
	if($count == 0) {
		update_option('payzen_available_languages', '');
		update_option('payzen_capture_delay', '');
		update_option('payzen_ctx_mode', 'TEST');
		update_option('payzen_gateway_url', 'https://secure.payzen.eu/vads-payment/');
		update_option('payzen_site_id', '12345678');
		update_option('payzen_key_test', '1111111111111111');
		update_option('payzen_key_prod', '2222222222222222');
		update_option('payzen_language', 'fr');
		update_option('payzen_validation_mode', '');
		update_option('payzen_payment_cards ', '');
		update_option('payzen_3ds_min', '');
		update_option('payzen_maximum_amount', '');
		update_option('payzen_minimum_amount', '');
		update_option('payzen_redirect_enabled', 0);
		update_option('payzen_redirect_success_timeout', 5);
		update_option('payzen_redirect_success_message','Redirection vers la boutique dans quelques instants...');
		update_option('payzen_redirect_error_timeout', 5);
		update_option('payzen_redirect_error_message', 'Redirection vers la boutique dans quelques instants...');
		update_option('payzen_return_mode', 'GET');
	}
}
	
add_action('init', 'init_payzen');
?>